============
Installation
============

At the command line, simply run: ::

    $ pip install pyeasyga

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pyeasyga
    $ pip install pyeasyga
